@@ -140,7 +140,7 @@ function PrintPreviewImpl(guiAction) {
     this.savedOffset = undefined;
 }
 
-PrintPreviewImpl.prototype = NewFile.getDefaultAction();
+PrintPreviewImpl.prototype = NewFile.getDefaultAction(false);
 PrintPreviewImpl.includeBasePath = includeBasePath;
 
 PrintPreviewImpl.State = {
@@ -245,7 +245,6 @@ PrintPreviewImpl.prototype.suspendEvent = function() {
 };
 
 PrintPreviewImpl.prototype.finishEvent = function() {
-    qDebug("PrintPreviewImpl.prototype.finishEvent");
     this.parentClass.prototype.finishEvent.call(this);
     var di = this.getDocumentInterface();
 
@@ -634,10 +633,11 @@ PrintPreviewImpl.prototype.slotPdfExport = function() {
         initialFileName = fileInfo.absoluteFilePath();
     }
 
-    var filters = [ "PDF File (*.pdf)" ];
+    var filterStrings = [ "PDF File (*.pdf)" ];
+    filterStrings = translateFilterStrings(filterStrings);
 
     var ret = File.getSaveFileName(appWin, qsTr("Export to PDF"),
-                   initialFileName, filters);
+                   initialFileName, filterStrings);
 
     if (isNull(ret)) {
         return;
